@@ -1,6 +1,6 @@
 /*
   SDL_net:  An example cross-platform network library for use with SDL
-  Copyright (C) 1997-2013 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2016 Sam Lantinga <slouken@libsdl.org>
   Copyright (C) 2012 Simeon Maxein <smaxein@googlemail.com>
 
   This software is provided 'as-is', without any express or implied
@@ -58,7 +58,7 @@ extern "C" {
 */
 #define SDL_NET_MAJOR_VERSION   2
 #define SDL_NET_MINOR_VERSION   0
-#define SDL_NET_PATCHLEVEL      0
+#define SDL_NET_PATCHLEVEL      1
 
 /* This macro can be used to fill a version structure with the compile-time
  * version of the SDL_net library.
@@ -310,11 +310,11 @@ extern DECLSPEC SDLNet_SocketSet SDLCALL SDLNet_AllocSocketSet(int maxsockets);
 
 /* Add a socket to a set of sockets to be checked for available data */
 extern DECLSPEC int SDLCALL SDLNet_AddSocket(SDLNet_SocketSet set, SDLNet_GenericSocket sock);
-static __inline__ int SDLNet_TCP_AddSocket(SDLNet_SocketSet set, TCPsocket sock)
+SDL_FORCE_INLINE int SDLNet_TCP_AddSocket(SDLNet_SocketSet set, TCPsocket sock)
 {
     return SDLNet_AddSocket(set, (SDLNet_GenericSocket)sock);
 }
-static __inline__ int SDLNet_UDP_AddSocket(SDLNet_SocketSet set, UDPsocket sock)
+SDL_FORCE_INLINE int SDLNet_UDP_AddSocket(SDLNet_SocketSet set, UDPsocket sock)
 {
     return SDLNet_AddSocket(set, (SDLNet_GenericSocket)sock);
 }
@@ -322,11 +322,11 @@ static __inline__ int SDLNet_UDP_AddSocket(SDLNet_SocketSet set, UDPsocket sock)
 
 /* Remove a socket from a set of sockets to be checked for available data */
 extern DECLSPEC int SDLCALL SDLNet_DelSocket(SDLNet_SocketSet set, SDLNet_GenericSocket sock);
-static __inline__ int SDLNet_TCP_DelSocket(SDLNet_SocketSet set, TCPsocket sock)
+SDL_FORCE_INLINE int SDLNet_TCP_DelSocket(SDLNet_SocketSet set, TCPsocket sock)
 {
     return SDLNet_DelSocket(set, (SDLNet_GenericSocket)sock);
 }
-static __inline__ int SDLNet_UDP_DelSocket(SDLNet_SocketSet set, UDPsocket sock)
+SDL_FORCE_INLINE int SDLNet_UDP_DelSocket(SDLNet_SocketSet set, UDPsocket sock)
 {
     return SDLNet_DelSocket(set, (SDLNet_GenericSocket)sock);
 }
@@ -345,7 +345,7 @@ extern DECLSPEC int SDLCALL SDLNet_CheckSockets(SDLNet_SocketSet set, Uint32 tim
    for reading.
 */
 #define SDLNet_SocketReady(sock) _SDLNet_SocketReady((SDLNet_GenericSocket)(sock))
-static __inline__ int _SDLNet_SocketReady(SDLNet_GenericSocket sock)
+SDL_FORCE_INLINE int _SDLNet_SocketReady(SDLNet_GenericSocket sock)
 {
     return (sock != NULL) && (sock->ready);
 }
@@ -382,36 +382,36 @@ extern DECLSPEC const char * SDLCALL SDLNet_GetError(void);
 
 #if !defined(WITHOUT_SDL) && !SDL_DATA_ALIGNED
 
-static __inline__ void _SDLNet_Write16(Uint16 value, void *areap)
+SDL_FORCE_INLINE void _SDLNet_Write16(Uint16 value, void *areap)
 {
     *(Uint16 *)areap = SDL_SwapBE16(value);
 }
 
-static __inline__ void _SDLNet_Write32(Uint32 value, void *areap)
+SDL_FORCE_INLINE void _SDLNet_Write32(Uint32 value, void *areap)
 {
     *(Uint32 *)areap = SDL_SwapBE32(value);
 }
 
-static __inline__ Uint16 _SDLNet_Read16(const void *areap)
+SDL_FORCE_INLINE Uint16 _SDLNet_Read16(const void *areap)
 {
     return SDL_SwapBE16(*(const Uint16 *)areap);
 }
 
-static __inline__ Uint32 _SDLNet_Read32(const void *areap)
+SDL_FORCE_INLINE Uint32 _SDLNet_Read32(const void *areap)
 {
     return SDL_SwapBE32(*(const Uint32 *)areap);
 }
 
 #else /* !defined(WITHOUT_SDL) && !SDL_DATA_ALIGNED */
 
-static __inline__ void _SDLNet_Write16(Uint16 value, void *areap)
+SDL_FORCE_INLINE void _SDLNet_Write16(Uint16 value, void *areap)
 {
     Uint8 *area = (Uint8*)areap;
     area[0] = (value >>  8) & 0xFF;
     area[1] =  value        & 0xFF;
 }
 
-static __inline__ void _SDLNet_Write32(Uint32 value, void *areap)
+SDL_FORCE_INLINE void _SDLNet_Write32(Uint32 value, void *areap)
 {
     Uint8 *area = (Uint8*)areap;
     area[0] = (value >> 24) & 0xFF;
@@ -420,13 +420,13 @@ static __inline__ void _SDLNet_Write32(Uint32 value, void *areap)
     area[3] =  value        & 0xFF;
 }
 
-static __inline__ Uint16 _SDLNet_Read16(void *areap)
+SDL_FORCE_INLINE Uint16 _SDLNet_Read16(void *areap)
 {
     Uint8 *area = (Uint8*)areap;
     return ((Uint16)area[0]) << 8 | ((Uint16)area[1]);
 }
 
-static __inline__ Uint32 _SDLNet_Read32(const void *areap)
+SDL_FORCE_INLINE Uint32 _SDLNet_Read32(const void *areap)
 {
     const Uint8 *area = (const Uint8*)areap;
     return ((Uint32)area[0]) << 24 | ((Uint32)area[1]) << 16 | ((Uint32)area[2]) << 8 | ((Uint32)area[3]);
